@@ -68,6 +68,7 @@ sub new {
 
     my $self = {
         '_confdir' => undef, # SYSCONFDIR replaced here from Makefile
+        '_options' => $params{options} // {},
     };
     bless $self, $class;
     $self->_loadDefaults();
@@ -78,19 +79,28 @@ sub new {
 
     $self->{vardir} = $params{vardir};
 
+    # To also keep vardir during reload
+    $self->{_options}->{vardir} = $params{vardir};
+
     $self->_checkContent();
 
     return $self;
 }
 
-sub reloadFromInputAndBackend {
+sub reload {
     my ($self) = @_;
 
     $self->_loadDefaults;
 
     $self->_loadFromBackend($self->{'conf-file'}, $self->{config});
 
+    # Reload script options and vardir
+    $self->_loadUserParams($self->{_options});
+
     $self->_checkContent();
+
+    # delaytime must not be used after a reload
+    $self->{delaytime} = 0;
 }
 
 sub _loadFromBackend {
@@ -213,7 +223,7 @@ sub loadFromFile {
     }
 
     while (my $line = <$handle>) {
-        if ($line =~ /^\s*([\w-]+)\s*=\s*(.+)$/) {
+        if ($line =~ /^\s*([\w-]+)\s*=\s*(.*)$/) {
             my $key = $1;
             my $val = $2;
 
@@ -420,6 +430,7 @@ sub getTargets {
     # create target list
     if ($self->{local}) {
         FusionInventory::Agent::Target::Local->require();
+        FusionInventory::Agent::Target::Local->reset();
         foreach my $path (@{$self->{local}}) {
             push @targets,
                 FusionInventory::Agent::Target::Local->new(
@@ -435,6 +446,8 @@ sub getTargets {
     if ($self->{server}) {
         FusionInventory::Agent::Target::Server->require();
         FusionInventory::Agent::Target::Scheduler->require();
+        FusionInventory::Agent::Target::Server->reset();
+        FusionInventory::Agent::Target::Scheduler->reset();
         foreach my $url (@{$self->{server}}) {
             my $server = FusionInventory::Agent::Target::Server->new(
                 logger     => $params{logger},
@@ -450,7 +463,7 @@ sub getTargets {
             # Schedule it to run every 2 minutes max by default
             my $scheduler = FusionInventory::Agent::Target::Scheduler->new(
                 logger      => $params{logger},
-                delaytime   => 60,
+                delaytime   => $self->{delaytime} ? 60 : 0,
                 maxDelay    => 120,
                 basevardir  => $params{vardir},
                 storage     => $server->getStorage(),
