@@ -63,7 +63,8 @@ sub _getInterfaces {
         );
 
         # check if it is a physical interface
-        if (-d "/sys/class/net/$interface->{DESCRIPTION}/device") {
+        if (-d "/sys/class/net/$interface->{DESCRIPTION}/device" &&
+           !-d "/sys/devices/virtual/net/$interface->{DESCRIPTION}") {
             my $info = _getUevent($interface->{DESCRIPTION});
             $interface->{DRIVER}  = $info->{DRIVER}
                 if $info->{DRIVER};
@@ -127,31 +128,37 @@ sub _getInterfaces {
             );
         }
 
-        if (-r "/sys/class/net/$interface->{DESCRIPTION}/speed") {
-            my $speed = getFirstLine(
-                file => "/sys/class/net/$interface->{DESCRIPTION}/speed"
-            );
-            $interface->{SPEED} = $speed if $speed;
-        }
-        # On older kernels, we should try ethtool system call for speed
-        if (!$interface->{SPEED}) {
-            $logger->debug("looking for interface speed from syscall:");
-            my $infos = getInterfacesInfosFromIoctl(
-                interface => $interface->{DESCRIPTION},
-                logger    => $logger
-            );
-            if ($infos->{SPEED}) {
-                $logger->debug_result(
-                    action => 'retrieving interface speed from syscall',
-                    data   => $infos->{SPEED}
-                );
-                $interface->{SPEED} = $infos->{SPEED};
-            } else {
-                $logger->debug_result(
-                    action => 'retrieving interface speed from syscall',
-                    status => 'syscall failed'
+        if (defined($interface->{STATUS}) && $interface->{STATUS} eq 'Up') {
+            if (-r "/sys/class/net/$interface->{DESCRIPTION}/speed") {
+                my $speed = getFirstLine(
+                    file => "/sys/class/net/$interface->{DESCRIPTION}/speed"
                 );
+                $interface->{SPEED} = $speed if $speed;
             }
+            # On older kernels, we should try ethtool system call for speed
+            if (!$interface->{SPEED}) {
+                $logger->debug("looking for interface speed from syscall:");
+                my $infos = getInterfacesInfosFromIoctl(
+                    interface => $interface->{DESCRIPTION},
+                    logger    => $logger
+                );
+                if ($infos->{SPEED}) {
+                    $logger->debug_result(
+                        action => 'retrieving interface speed from syscall',
+                        data   => $infos->{SPEED}
+                    );
+                    $interface->{SPEED} = $infos->{SPEED};
+                } else {
+                    $logger->debug_result(
+                        action => 'retrieving interface speed from syscall',
+                        status => 'syscall failed'
+                    );
+                }
+            }
+        } else {
+            # Report zero speed in case the interface went from up to down
+            # or the server has non-zero interface speed
+            $interface->{SPEED} = 0;
         }
     }
 
