@@ -117,39 +117,45 @@ sub getCanonicalManufacturer {
         TMx86        => 'Transmeta',
         TransmetaCPU => 'Transmeta',
         CyrixInstead => 'Cyrix',
-        CentaurHauls => 'VIA'
+        CentaurHauls => 'VIA',
+        HygonGenuine => 'Hygon'
+    );
+
+    my %regexp = (
+        "Apple"           => qr/^APPLE/i,
+        "Hewlett-Packard" => qr/^(hp|HPE?|(?i)hewlett[ -]packard)/,
+        "Hitachi"         => qr/^(HD|IC|HU|HGST)/,
+        "Seagate"         => qr/^(ST|(?i)seagate)/,
+        "Sony"            => qr/^OPTIARC/i,
+        "Western Digital" => qr/^(WDC|(?i)western)/,
     );
 
     if (exists $manufacturers{$manufacturer}) {
         $manufacturer = $manufacturers{$manufacturer};
     } elsif ($manufacturer =~ /(
-        maxtor    |
-        sony      |
-        compaq    |
-        ibm       |
-        toshiba   |
-        fujitsu   |
-        lg        |
-        samsung   |
-        nec       |
-        transcend |
-        matshita  |
-        hitachi   |
-        pioneer
+        \blg\b     |
+        broadcom   |
+        compaq     |
+        dell       |
+        fujitsu    |
+        hitachi    |
+        ibm        |
+        intel      |
+        matshita   |
+        maxtor     |
+        nvidia     |
+        \bnec\b    |
+        pioneer    |
+        samsung    |
+        sony       |
+        supermicro |
+        toshiba    |
+        transcend
     )/xi) {
         $manufacturer = ucfirst(lc($1));
-    } elsif ($manufacturer =~ /^(hp|HP|(?i)hewlett[ -]packard)/) {
-        $manufacturer = "Hewlett-Packard";
-    } elsif ($manufacturer =~ /^(WDC|(?i)western)/) {
-        $manufacturer = "Western Digital";
-    } elsif ($manufacturer =~ /^(ST|(?i)seagate)/) {
-        $manufacturer = "Seagate";
-    } elsif ($manufacturer =~ /^(HD|IC|HU|HGST)/) {
-        $manufacturer = "Hitachi";
-    } elsif ($manufacturer =~ /^APPLE/i) {
-        $manufacturer = "Apple";
-    } elsif ($manufacturer =~ /^OPTIARC/i) {
-        $manufacturer = "Sony";
+    } else {
+        my $match = first { $manufacturer =~ $regexp{$_} } keys %regexp;
+        $manufacturer = $match if $match;
     }
 
     return $manufacturer;
@@ -213,7 +219,13 @@ sub getCanonicalSize {
     return undef unless $size =~ /^([,.\d]+) (\S+)$/x;
     my $value = $1;
     my $unit = lc($2);
-    $value =~ s/,/\./;
+
+    # check if the number has groups separated by commas or spaces
+    if ($value =~ /^(0|[1-9](\d*|\d{0,2}([, ]\d{3})+))(\.\d+)?$/) {
+        $value =~ s/,| //g;
+    } else {
+        $value =~ s/,/\./;
+    }
 
     return
         $unit eq 'tb'    ? $value * $base * $base        :
@@ -355,7 +367,7 @@ sub getFirstLine {
     my $result = <$handle>;
     close $handle;
 
-    chomp $result if $result;
+    chomp $result if defined $result;
     return $result;
 }
 
@@ -371,7 +383,7 @@ sub getLastLine {
     }
     close $handle;
 
-    chomp $result if $result;
+    chomp $result if defined $result;
     return $result;
 }
 
@@ -829,4 +841,4 @@ Return the content of a given file.
 
 =head2 isParamArrayAndFilled($hash, $paramName)
 
-Return if $hash has a key $paramName which value is a ARRAY ref not empty.
\ No newline at end of file
+Return if $hash has a key $paramName which value is a ARRAY ref not empty.
